@@ -44,6 +44,23 @@
  */
 #define DEFAULT_SERVER "localhost irc.efnet.net irc.undernet.org irc.dalnet.org irc.worldirc.org"
 
+/*
+ * Oooops!  This was supposed to be here, but it never did make it.  Which
+ * explains a lot.  Anyhow, #define this if you want to have the option of
+ * doing floating point math in EPIC.  #undef this if you always want integer
+ * operations to always be done.  The client can still do integer operations 
+ * if this is defined, just /set floating_point_math OFF.
+ *
+ * Note that if this is defined, the client actually will do all of your
+ * operations in floating point and then the *result* will be truncated.
+ * This is different from when this is #undef when *each term* will be 
+ * truncated.  For example:
+ *
+ * 	#undef'd  4.2 - 2.6 	-> (4 - 2) -> 2
+ *	#define'd 4.2 - 2.6     -> 1.6 -> 1
+ */
+#define FLOATING_POINT_SUPPORT
+
 /*
  * Undef this if your FIONREAD is not useful.  At this time, it makes very
  * little difference because we dont use FIONREAD for anything useful.  But
