@@ -1838,8 +1838,13 @@ void 	panic_dump_call_stack 	(void)
 {
 	int my_wind_index = wind_index;
 	printf("Call stack\n");
-	while (my_wind_index--)
-		printf("[%3d] %s\n", my_wind_index, call_stack[my_wind_index].current);
+	if (wind_index >= 0)
+	{
+		while (my_wind_index--)
+			printf("[%3d] %s\n", my_wind_index, call_stack[my_wind_index].current);
+	}
+	else
+		printf("Stack is corrupted, sorry.\n");
 	printf("End of call stack\n");
 }
 
