@@ -698,8 +698,12 @@ BUILT_IN_COMMAND(e_privmsg)
 		send_text(nick, args, command, window_display);
 		malloc_strcpy(&sent_body, args);
 	}
-	else
-		say("Usage: /%s <nickname|channel|*> <text>", command);
+	else 
+	{
+		if (!strcmp(command, "PRIVMSG"))
+			command = "MSG";	/* *cough* */
+		say("Usage: /%s <[=]nickname|channel|*> <text>", command);
+	}
 }
 
 /* e_quit: The /QUIT, /EXIT, etc command */
@@ -724,8 +728,12 @@ BUILT_IN_COMMAND(e_quit)
  */
 BUILT_IN_COMMAND(e_topic)
 {
-	char *arg;
-	char *channel = get_channel_by_refnum(0);
+	char 	*arg;
+	char 	*channel = get_channel_by_refnum(0);
+	int	clear_topic = 0;
+
+	if (*args == '-')
+		clear_topic = 1, args++;
 
 	if (!(arg = next_arg(args, &args)))
 		arg = channel;
@@ -733,10 +741,14 @@ BUILT_IN_COMMAND(e_topic)
 		arg = channel;
 
 	if (!arg)
-		say("You are not on a channel in this window.");
-	else if (is_channel(arg))
 	{
-		if (args && *args)
+		say("You are not on a channel in this window.");
+		return;
+	}
+
+	if (is_channel(arg))
+	{
+		if ((args && *args) || clear_topic)
 			send_to_server("%s %s :%s", command, arg, args);
 		else
 			send_to_server("%s %s", command, arg);
