@@ -139,9 +139,6 @@ static	char	*next_unit (char *str, char *args, int *arg_flag, int stage)
  */
 #define SETUP_IMPLIED(var1, var2, func)					\
 {									\
-/*	char *result1 = NULL,			*/			\
-	    /* *result2 = NULL;			*/			\
-									\
 	/* Save the type of op, skip over the X=. */			\
 	op = *ptr;							\
 	*ptr++ = '\0';							\
@@ -199,8 +196,6 @@ static	char	*next_unit (char *str, char *args, int *arg_flag, int stage)
  */
 #define SETUP_BINARY(var1, var2, func)					\
 {									\
-	/*char *result1 = NULL, *result2 = NULL; */			\
-									\
 	/* Save the op were working on cause we clobber it. */		\
 	op = *ptr;							\
 	*ptr++ = '\0';							\
@@ -1332,11 +1327,13 @@ char	*expand_alias	(char *string, char *args, int *args_flag, char **more_text)
 
 			m_strcat_ues(&buffer, stuff, unescape);
 
-			while (*ptr == '^')
+			for (; *ptr == '^'; ptr++)
 			{
-				quote_temp[0] = *++ptr;
-				malloc_strcat(&quote_str, quote_temp);
 				ptr++;
+				if (!*ptr)	/* Blah */
+					break;
+				quote_temp[0] = *ptr;
+				malloc_strcat(&quote_str, quote_temp);
 			}
 			stuff = alias_special_char(&buffer, ptr, args, quote_str, args_flag);
 			if (quote_str)		/* Why ``stuff''? */
