@@ -87,8 +87,8 @@ void cursor_to_input (void)
 			output_screen = screen;
 			last_input_screen = screen;
 			term_move_cursor(INPUT_CURSOR, INPUT_LINE);
-			cursor_not_in_display();
 			term_flush();
+			cursor_not_in_display(screen);
 		}
 	}
 	output_screen = last_input_screen = oldscreen;
