@@ -13,13 +13,13 @@
 /*
  * irc_version is what $J returns, its the common-name for the version.
  */
-const char irc_version[] = "EPIC4pre1.201";
+const char irc_version[] = "EPIC4pre1.300";
 
 /*
  * internal_version is what $V returns, its the integer-id for the
  * version, and corresponds to the date of release, YYYYMMDD.
  */ 
-const char internal_version[] = "19980529";
+const char internal_version[] = "19980617";
 
 
 #include "status.h"
@@ -463,7 +463,6 @@ static	void	parse_args (int argc, char **argv)
 	if ((ptr = getenv("IRCNICK")))
 		strmcpy(nickname, ptr, NICKNAME_LEN);
 
-
 	/*
 	 * We now allow users to use IRCUSER or USER if we couldnt get the
 	 * username from the password entries.  For those systems that use
@@ -639,7 +638,7 @@ static	void	parse_args (int argc, char **argv)
 	argc -= optind;
 	argv += optind;
 
-	if (argc && **argv)
+	if (argc && **argv && !strchr(*argv, '.'))
 		strmcpy(nickname, *argv++, NICKNAME_LEN), argc--;
 	for (; *argv; argc--, argv++)
 		if (**argv)
