@@ -2494,3 +2494,18 @@ char	*strpcat (char *source, const char *format, ...)
 	strcat(source, buffer);
 	return source;
 }
+
+u_char	*strcpy_nocolorcodes (u_char *dest, const u_char *source)
+{
+	u_char	*save = dest;
+
+	do
+	{
+		if (*source == 3)
+			source = skip_ctl_c_seq(source, NULL, NULL);
+		*dest++ = *source;
+	}
+	while (*source++);
+
+	return save;
+}
