@@ -625,12 +625,12 @@ void numbered_command (char *from, int comm, char **ArgList)
 	case 374:		/* #define RPL_ENDOFINFO        374 */
 	case 394:		/* #define RPL_ENDOFUSERS       394 */
 	{
-		if (get_int_var(SHOW_END_OF_MSGS_VAR))
-		{
-			PasteArgs(ArgList, 0);
-			if (do_hook(current_numeric, "%s %s", from, *ArgList))
-				display_msg(from, ArgList);
-		}
+		int hook;
+
+		PasteArgs(ArgList, 0);
+		hook = do_hook(current_numeric, "%s %s", from, *ArgList);
+		if (hook && get_int_var(SHOW_END_OF_MSGS_VAR))
+			display_msg(from, ArgList);
 		break;
 	}
 
