@@ -409,12 +409,14 @@ static void p_quit (char *from, char **ArgList)
 			message_from(chan, LOG_CRAP);
 			if (do_hook(CHANNEL_SIGNOFF_LIST, "%s %s %s", chan, from, Reason))
 				one_prints = 1;
+			message_from((char *) 0, LOG_CURRENT);
 		}
 		if (one_prints)
 		{
 			message_from(what_channel(from), LOG_CRAP);
 			if (do_hook(SIGNOFF_LIST, "%s %s", from, Reason))
 				say("Signoff: %s (%s)", from, Reason);
+			message_from((char *) 0, LOG_CURRENT);
 		}
 	}
 	notify_mark(from, 0, 0);
@@ -978,11 +980,20 @@ void 	parse_server (char *line)
 	else if (!do_hook(RAW_IRC_LIST, "* %s", line))
 		return;
 
-#ifdef STRIP_ESCAPES
+#ifdef INCOMING_STRIPPERS
+	if (strip_escapes)
 	{
-	char *c = line;
-	while ((c = strchr(c, 27)))
-		*c++ = '[';
+		char *c = line;
+		while ((c = strchr(c, 27)))
+			*c++ = '[';
+	}
+	else if (strip_ansi_codes)
+	{
+		/* ... */
+	}
+	else if (strip_color_codes)
+	{
+		/* ... */
 	}
 #endif
 
