@@ -400,7 +400,7 @@ void 	add_to_window (Window *window, const unsigned char *str)
 			}
 		}
 
-		cursor_in_display();
+		cursor_in_display(window);
 	}
 }
 
@@ -1407,10 +1407,12 @@ static int	display_color (long color1, long color2)
  * physical position of the cursor, but it will force rite() to reset the
  * cursor upon its next call 
  */
-void 	cursor_not_in_display (void)
+void 	cursor_not_in_display (Screen *s)
 {
-	if (current_window->screen)
-		current_window->screen->cursor_window = NULL;
+	if (!s)
+		s = output_screen;
+	if (s->cursor_window)
+		s->cursor_window = NULL;
 }
 
 /*
@@ -1420,10 +1422,12 @@ void 	cursor_not_in_display (void)
  * cursor is in a window, thus letting the input updating routines move the
  * cursor down to the input line.  Dumb dumb dumb 
  */
-void 	cursor_in_display (void)
+void 	cursor_in_display (Window *w)
 {
-	if (current_window->screen)
-		current_window->screen->cursor_window = current_window;
+	if (!w)
+		w = current_window;
+	if (w->screen)
+		w->screen->cursor_window = w;
 }
 
 /*
