@@ -188,6 +188,8 @@ void	do_server (fd_set *rd)
 				break;
 			case -1:
 			{
+				int	sopen = is_server_connected(i);
+
 				close_server(i, empty_string);
 				say("Connection closed from %s: %s", 
 					server_list[i].name,
@@ -195,6 +197,14 @@ void	do_server (fd_set *rd)
 					     "Remote end closed connection" : 
 					     strerror(dgets_errno));
 
+				/*
+				 * If we were never connected to the server,
+				 * eg, they rejected us at registration time,
+				 * then we will just move on to the next
+				 * server in the list.
+				 */
+				if (!sopen)
+					i++;
 				get_connected(i, i);
 				break;
 			}
