@@ -557,13 +557,13 @@ enum VAR_TYPES	sv_index;
 		if (hook)
 		{
 			hook = do_hook(SET_LIST, "%s %s", 
-				var, args ? args : empty_string);
+				var, args ? args : "<unset>");
 
 			if (hook && (cnt < 0))
 			{
 				hook = do_hook(SET_LIST, "%s %s",
 					irc_variable[sv_index].name, 
-					args ? args : empty_string);
+					args ? args : "<unset>");
 			}
 		}
 
