@@ -1267,12 +1267,25 @@ static void 	show_window (Window *window)
  */
 Window *get_window_by_desc (char *stuff)
 {
+	Window	*w = NULL;	/* bleh */
+
+   do
+   {
+	if ((w = get_window_by_name(stuff)))
+		break;
+
+	if (is_number(stuff) && (w = get_window_by_refnum(my_atol(stuff))))
+		break;
+
 	if (*stuff == '#')
+	{
 		stuff++;
-	if (is_number(stuff))
-		return get_window_by_refnum(my_atol(stuff));
-	else
-		return get_window_by_name(stuff);
+		continue;
+	}
+    }
+    while (0);
+
+	return w;
 }
 
 
@@ -1890,7 +1903,7 @@ void 	message_from (const char *who, int level)
 	 * This uncomplicates a lot of stuff.  Why do i know this
 	 * is going to backfire on me?
 	 */
-	if (level == LOG_CURRENT || level == LOG_CRAP)
+	if (level == LOG_CURRENT)
 		set_lastlog_msg_level(saved_lastlog_level);
 	else
 		saved_lastlog_level = set_lastlog_msg_level(level);
@@ -2471,8 +2484,11 @@ static Window *window_bind (Window *window, char **args)
  */
 Window *window_channel (Window *window, char **args)
 {
-	char *sarg, *arg;
-	Window *w = NULL, *other = NULL;
+	char 	*sarg, 
+		*arg,
+		*arg2 = NULL;
+	Window 	*w = NULL, 
+		*other = NULL;
 
 	if ((sarg = new_next_arg(*args, args)))
 	{
@@ -2493,6 +2509,17 @@ Window *window_channel (Window *window, char **args)
 			}
 		}
 
+		/*
+		 * We do some chicanery here. :/
+		 * For some complicated reasons, new_next_arg skips over
+		 * backslashed quotation marks.  Usually what happens down
+		 * the line is that the backslash eventually gets unescaped.
+		 * Well, not here.  So we have to do this manually.  This is
+		 * a quick, and nasty hack, but i will re-assess the
+		 * situation later and improve what is being done here.
+		 */
+		arg = m_strcat_ues(&arg2, arg, 1);
+
 		while (traverse_all_windows(&w))
 		{
 			if (w == window || w->server != window->server)
@@ -2502,6 +2529,7 @@ Window *window_channel (Window *window, char **args)
 				!my_stricmp(arg, w->bind_channel))
 			{
 			    say("Channel %s is already bound elsewhere", arg);
+			    new_free(&arg2);
 			    return window;
 			}
 
@@ -2532,6 +2560,8 @@ Window *window_channel (Window *window, char **args)
 			malloc_strcpy(&window->waiting_channel, arg);
 			from_server = server;
 		}
+
+		new_free(&arg2);
 	}
 	else
 		set_channel_by_refnum(window->refnum, zero);
@@ -3790,7 +3820,7 @@ void 	scrollback_backwards_lines (int lines)
 	window->lines_scrolled_back += new_lines;
 	recalculate_window_cursor(window);
 	repaint_window(window, 0, -1);
-	cursor_not_in_display();
+	cursor_not_in_display(window->screen);
 	update_input(UPDATE_JUST_CURSOR);
 }
 
@@ -3817,7 +3847,7 @@ void 	scrollback_forwards_lines (int lines)
 	window->lines_scrolled_back -= new_lines;
 	recalculate_window_cursor(window);
 	repaint_window(window, 0, -1);
-	cursor_not_in_display();
+	cursor_not_in_display(window->screen);
 	update_input(UPDATE_JUST_CURSOR);
 
 	if (window->lines_scrolled_back <= 0)
@@ -3870,7 +3900,7 @@ void 	scrollback_end (char dumb, char *dumber)
 	window->lines_scrolled_back = 0;
 	window->scrollback_point = NULL;
 	repaint_window(window, 0, -1);
-	cursor_not_in_display();
+	cursor_not_in_display(window->screen);
 	update_input(UPDATE_JUST_CURSOR);
 
 #if 0		/* Dont do this, people dont like it */
@@ -3899,7 +3929,7 @@ void 	scrollback_start (char dumb, char *dumber)
 	}
 
 	repaint_window(window, 0, -1);
-	cursor_not_in_display();
+	cursor_not_in_display(window->screen);
 	update_input(UPDATE_JUST_CURSOR);
 }
 
@@ -3941,7 +3971,7 @@ void	hold_mode (Window *window, int flag, int update)
 		update_window_status(window, 0);
 		if (window->update | UPDATE_STATUS)
 			window->update -= UPDATE_STATUS;
-		cursor_in_display();
+		cursor_in_display(window);
 		update_input(NO_UPDATE);
 	}
 }
